function setup_walls(objects,map,room_border_tiles)
	objects.walls = {}

	process_map(objects,map,room_border_tiles)
end

function process_map(objects,map,room_border_tiles)
	for y_index,value in ipairs(map) do
		for x_index,tile in ipairs(value) do
			--tile_alg_1(tile,objects,x_index,y_index)
			tile_alg_2(tile,objects,x_index,y_index)
			--tile_alg_3(tile,objects,x_index,y_index)
		end
	end
	--tile_alg_4(map,room_border_tiles,objects)
	local map_border_lines = {}
	
	map_border_lines.top = {}
	map_border_lines.bottom = {}
	map_border_lines.right = {}
	map_border_lines.left = {}

	local top_left = {0,0}
	local top_right = {#map[1]*tilesize,0}
	local bottom_left = {0,#map*tilesize}
	local bottom_right = {#map[1]*tilesize,#map*tilesize}

	map_border_lines.top.body = love.physics.newBody(world,0,0)
	map_border_lines.top.shape = love.physics.newEdgeShape(top_left[1],top_left[2],top_right[1],top_right[2])
	map_border_lines.top.fixture = love.physics.newFixture(map_border_lines.top.body, map_border_lines.top.shape)

	map_border_lines.bottom.body = love.physics.newBody(world,0,0)
	map_border_lines.bottom.shape = love.physics.newEdgeShape(bottom_left[1],bottom_left[2],bottom_right[1],bottom_right[2])
	map_border_lines.bottom.fixture = love.physics.newFixture(map_border_lines.bottom.body, map_border_lines.bottom.shape)

	map_border_lines.right.body = love.physics.newBody(world,0,0)
	map_border_lines.right.shape = love.physics.newEdgeShape(top_right[1],top_right[2],bottom_right[1],bottom_right[2])
	map_border_lines.right.fixture = love.physics.newFixture(map_border_lines.right.body,map_border_lines.right.shape)

	map_border_lines.left.body = love.physics.newBody(world,0,0)
	map_border_lines.left.shape = love.physics.newEdgeShape(top_left[1],top_left[2],bottom_left[1],bottom_left[2])
	map_border_lines.left.fixture = love.physics.newFixture(map_border_lines.left.body, map_border_lines.left.shape)

	table.insert(objects.walls,map_border_lines.top)
	table.insert(objects.walls,map_border_lines.bottom)
end

function tile_alg_1(tile,objects,x_index,y_index)
	if tile == 1 then
		--check to see if adjacent tiles are floortiles or not
		local top_left = {x_index*tilesize-tilesize, y_index*tilesize-tilesize}
		local top_right = {x_index*tilesize, y_index*tilesize-tilesize}
		local bottom_left = {x_index*tilesize-tilesize, y_index*tilesize}
		local bottom_right = {x_index*tilesize,y_index*tilesize}

		local ran_sucessfully = {}
		local return_values = {}
		ran_sucessfully.above, return_values.above = pcall(function () return map[y_index-1][x_index] == 2 end)
		ran_sucessfully.below, return_values.below = pcall(function () return map[y_index+1][x_index] == 2 end)
		ran_sucessfully.right, return_values.right = pcall(function () return map[y_index][x_index+1] == 2 end)
		ran_sucessfully.left, return_values.left = pcall(function () return map[y_index][x_index-1] == 2 end)
		if ran_sucessfully.above and return_values.above then --check if the tile directly above is floor
			local edge_above = {}
			edge_above.body = love.physics.newBody(world,0,0)
			edge_above.shape = love.physics.newEdgeShape(top_left[1],top_left[2],top_right[1],top_right[2])
			edge_above.fixture = love.physics.newFixture(edge_above.body,edge_above.shape)
			table.insert(objects.walls,edge_above)
		end
		if ran_sucessfully.below and return_values.below then --etc,etc
			local edge_below = {}
			edge_below.body = love.physics.newBody(world,0,0)
			edge_below.shape = love.physics.newEdgeShape(bottom_left[1],bottom_left[2],bottom_right[1],bottom_right[2])
			edge_below.fixture = love.physics.newFixture(edge_below.body,edge_below.shape)
			table.insert(objects.walls,edge_below)
		end
		if ran_sucessfully.right and return_values.right then --etc,etc
			local edge_right = {}
			edge_right.body = love.physics.newBody(world,0,0)
			edge_right.shape = love.physics.newEdgeShape(top_right[1],top_right[2],bottom_right[1],bottom_right[2])
			edge_right.fixture = love.physics.newFixture(edge_right.body,edge_right.shape)
			table.insert(objects.walls,edge_right)
		end
		if ran_sucessfully.left and return_values.left then --etc,etc
			local edge_left = {}
			edge_left.body = love.physics.newBody(world,0,0)
			edge_left.shape = love.physics.newEdgeShape(top_left[1],top_left[2],bottom_left[1],bottom_left[2])
			edge_left.fixture = love.physics.newFixture(edge_left.body,edge_left.shape)
			table.insert(objects.walls,edge_left)
		end
	end
end
function tile_alg_2(tile,objects,x_index,y_index)
	if tile == 2 then
				--check to see if adjacent tiles are floortiles or not
		local top_left = {x_index*tilesize-tilesize, y_index*tilesize-tilesize}
		local top_right = {x_index*tilesize, y_index*tilesize-tilesize}
		local bottom_left = {x_index*tilesize-tilesize, y_index*tilesize}
		local bottom_right = {x_index*tilesize,y_index*tilesize}

		local ran_sucessfully = {}
		local return_values = {}

		ran_sucessfully.above, return_values.above = pcall(function () return map[y_index-1][x_index] == 1 end)
		ran_sucessfully.below, return_values.below = pcall(function () return map[y_index+1][x_index] == 1 end)
		ran_sucessfully.right, return_values.right = pcall(function () return map[y_index][x_index+1] == 1 end)
		ran_sucessfully.left, return_values.left = pcall(function () return map[y_index][x_index-1] == 1 end)

				
		if ran_sucessfully.below and return_values.below then --etc,etc
			local edge_below = {}
			edge_below.body = love.physics.newBody(world,0,0)
			edge_below.shape = love.physics.newEdgeShape(bottom_left[1],bottom_left[2],bottom_right[1],bottom_right[2])
			edge_below.fixture = love.physics.newFixture(edge_below.body,edge_below.shape)
			table.insert(objects.walls,edge_below)
		end
		if ran_sucessfully.right and return_values.right then --etc,etc
			local edge_right = {}
			edge_right.body = love.physics.newBody(world,0,0)
			edge_right.shape = love.physics.newEdgeShape(top_right[1],top_right[2],bottom_right[1],bottom_right[2])
			edge_right.fixture = love.physics.newFixture(edge_right.body,edge_right.shape)
			table.insert(objects.walls,edge_right)
		end
		if ran_sucessfully.left and return_values.left then --etc,etc
			local edge_left = {}
			edge_left.body = love.physics.newBody(world,0,0)
			edge_left.shape = love.physics.newEdgeShape(top_left[1],top_left[2],bottom_left[1],bottom_left[2])
			edge_left.fixture = love.physics.newFixture(edge_left.body,edge_left.shape)
			table.insert(objects.walls,edge_left)
		end
		if ran_sucessfully.above and return_values.above then --check if the tile directly above is solid
			local edge_above = {}
			edge_above.body = love.physics.newBody(world,0,0)
			edge_above.shape = love.physics.newEdgeShape(top_left[1],top_left[2],top_right[1],top_right[2])
			edge_above.fixture = love.physics.newFixture(edge_above.body,edge_above.shape)
			table.insert(objects.walls,edge_above)
		end
	end
end

function tile_alg_3(tile,objects,x_index,y_index)
	if tile == 1 then
		--check to see if adjacent tiles are floortiles or not
		local top_left = {x_index*tilesize-tilesize, y_index*tilesize-tilesize}
		local top_right = {x_index*tilesize, y_index*tilesize-tilesize}
		local bottom_left = {x_index*tilesize-tilesize, y_index*tilesize}
		local bottom_right = {x_index*tilesize,y_index*tilesize}

		local ran_sucessfully = {}
		local return_values = {}
		ran_sucessfully.above, return_values.above = pcall(function () return map[y_index-1][x_index] == 2 end)
		ran_sucessfully.below, return_values.below = pcall(function () return map[y_index+1][x_index] == 2 end)
		ran_sucessfully.right, return_values.right = pcall(function () return map[y_index][x_index+1] == 2 end)
		ran_sucessfully.left, return_values.left = pcall(function () return map[y_index][x_index-1] == 2 end)
		
		local edge_above = {}
		edge_above.body = love.physics.newBody(world,0,0)
		edge_above.shape = love.physics.newEdgeShape(top_left[1],top_left[2],top_right[1],top_right[2])
		edge_above.fixture = love.physics.newFixture(edge_above.body,edge_above.shape)
		table.insert(objects.walls,edge_above)
	
		local edge_below = {}
		edge_below.body = love.physics.newBody(world,0,0)
		edge_below.shape = love.physics.newEdgeShape(bottom_left[1],bottom_left[2],bottom_right[1],bottom_right[2])
		edge_below.fixture = love.physics.newFixture(edge_below.body,edge_below.shape)
		table.insert(objects.walls,edge_below)
				
		local edge_right = {}
		edge_right.body = love.physics.newBody(world,0,0)
		edge_right.shape = love.physics.newEdgeShape(top_right[1],top_right[2],bottom_right[1],bottom_right[2])
		edge_right.fixture = love.physics.newFixture(edge_right.body,edge_right.shape)
		table.insert(objects.walls,edge_right)

		local edge_left = {}
		edge_left.body = love.physics.newBody(world,0,0)
		edge_left.shape = love.physics.newEdgeShape(top_left[1],top_left[2],bottom_left[1],bottom_left[2])
		edge_left.fixture = love.physics.newFixture(edge_left.body,edge_left.shape)
		table.insert(objects.walls,edge_left)
	end
end
function tile_alg_4(map,room_border_tiles,objects)
	for i,v in ipairs(room_border_tiles) do --y,x
		if map[v[1]][v[2]] == 1 then
			local top_left = {v[2]*tilesize-tilesize, v[1]*tilesize-tilesize}
			local top_right = {v[2]*tilesize, v[1]*tilesize-tilesize}
			local bottom_left = {v[2]*tilesize-tilesize, v[1]*tilesize}
			local bottom_right = {v[2]*tilesize,v[1]*tilesize}

			ran_sucessfully = {}
			return_values = {}
			ran_sucessfully.above, return_values.above = pcall(function () return map[v[1]-1][v[2]] == 2 end)
			ran_sucessfully.below, return_values.below = pcall(function () return map[v[1]+1][v[2]] == 2 end)
			ran_sucessfully.right, return_values.right = pcall(function () return map[v[1]][v[2]+1] == 2 end)
			ran_sucessfully.left, return_values.left = pcall(function () return map[v[1]][v[2]-1] == 2 end)
			--[[
			if ran_sucessfully.below and return_values.below then --etc,etc
				local edge_below = {}
				edge_below.body = love.physics.newBody(world,0,0)
				edge_below.shape = love.physics.newEdgeShape(bottom_left[1],bottom_left[2],bottom_right[1],bottom_right[2])
				edge_below.fixture = love.physics.newFixture(edge_below.body,edge_below.shape)
				table.insert(objects.walls,edge_below)
			end
			if ran_sucessfully.right and return_values.right then --etc,etc
				local edge_right = {}
				edge_right.body = love.physics.newBody(world,0,0)
				edge_right.shape = love.physics.newEdgeShape(top_right[1],top_right[2],bottom_right[1],bottom_right[2])
				edge_right.fixture = love.physics.newFixture(edge_right.body,edge_right.shape)
				table.insert(objects.walls,edge_right)
			end
			if ran_sucessfully.left and return_values.left then --etc,etc
				local edge_left = {}
				edge_left.body = love.physics.newBody(world,0,0)
				edge_left.shape = love.physics.newEdgeShape(top_left[1],top_left[2],bottom_left[1],bottom_left[2])
				edge_left.fixture = love.physics.newFixture(edge_left.body,edge_left.shape)
				table.insert(objects.walls,edge_left)
			end
			if ran_sucessfully.above and return_values.above then --check if the tile directly above is solid
				local edge_above = {}
				edge_above.body = love.physics.newBody(world,0,0)
				edge_above.shape = love.physics.newEdgeShape(top_left[1],top_left[2],top_right[1],top_right[2])
				edge_above.fixture = love.physics.newFixture(edge_above.body,edge_above.shape)
				table.insert(objects.walls,edge_above)
			end
			]]
			if v[3] == "above" then --etc,etc
				local edge_below = {}
				edge_below.body = love.physics.newBody(world,0,0)
				edge_below.shape = love.physics.newEdgeShape(bottom_left[1],bottom_left[2],bottom_right[1],bottom_right[2])
				edge_below.fixture = love.physics.newFixture(edge_below.body,edge_below.shape)
				table.insert(objects.walls,edge_below)
			end
			if v[3] == "left" then --etc,etc
				local edge_right = {}
				edge_right.body = love.physics.newBody(world,0,0)
				edge_right.shape = love.physics.newEdgeShape(top_right[1],top_right[2],bottom_right[1],bottom_right[2])
				edge_right.fixture = love.physics.newFixture(edge_right.body,edge_right.shape)
				table.insert(objects.walls,edge_right)
			end
			if v[3] == "right" then --etc,etc
				local edge_left = {}
				edge_left.body = love.physics.newBody(world,0,0)
				edge_left.shape = love.physics.newEdgeShape(top_left[1],top_left[2],bottom_left[1],bottom_left[2])
				edge_left.fixture = love.physics.newFixture(edge_left.body,edge_left.shape)
				table.insert(objects.walls,edge_left)
			end
			if v[3] == "bottom" then --check if the tile directly above is solid
				local edge_above = {}
				edge_above.body = love.physics.newBody(world,0,0)
				edge_above.shape = love.physics.newEdgeShape(top_left[1],top_left[2],top_right[1],top_right[2])
				edge_above.fixture = love.physics.newFixture(edge_above.body,edge_above.shape)
				table.insert(objects.walls,edge_above)
			end
		end
	end
end