require "libraries.map_generator"
cam=require "libraries.hump.camera"

require "functions.player"
require "functions.walls"

function love.load()
	
	Camera = cam()
	
	tileset=love.graphics.newImage("tileset.png")
	love.window.setMode( 1366, 768, {resizable=true} )
	tileset_quadinfo={
	{0,0}, --solid
	{96,0} --floor
	}
	tileset_quads = create_quads(tileset_quadinfo,96,96,192,384)
	
	love.physics.setMeter(48)
	tilesize = 96
	world = love.physics.newWorld(0,0, true)

	map,border_tiles=generate_map(40,20,5,5,7,7)

	viable_spawn_points = {}

	for rowindex,row in ipairs(map) do
		for columnindex,tile in ipairs(row) do
			if tile == 2 then
				table.insert(viable_spawn_points,{rowindex*tilesize-tilesize,columnindex*tilesize-tilesize}) --y,x
			end
		end
	end

	objects = {}

	setup_player(objects)

	setup_walls(objects,map,border_tiles)

	--[[for y_index,value in ipairs(map) do
		for x_index,tile in ipairs(value) do
			if tile == 1 then
				--check to see if adjacent tiles are floortiles or not
				local top_left = {x_index*tilesize-tilesize, y_index*tilesize-tilesize}
				local top_right = {x_index*tilesize, y_index*tilesize-tilesize}
				local bottom_left = {x_index*tilesize-tilesize, y_index*tilesize}
				local bottom_right = {x_index*tilesize,y_index*tilesize}

				local ran_sucessfully = {}
				local return_values = {}

				ran_sucessfully.above, return_values.above = pcall(function () return map[y_index-1][x_index] == 2 end)
				ran_sucessfully.below, return_values.below = pcall(function () return map[y_index+1][x_index] == 2 end)
				ran_sucessfully.right, return_values.right = pcall(function () return map[y_index][x_index+1] == 2 end)
				ran_sucessfully.left, return_values.left = pcall(function () return map[y_index][x_index-1] == 2 end)
				if return_values.above then --check if the tile directly above is floor
					local edge_above = {}
					edge_above.body = love.physics.newBody(world,0,0)
					edge_above.shape = love.physics.newEdgeShape(top_left[1],top_left[2],top_right[1],top_right[2])
					edge_above.fixture = love.physics.newFixture(edge_above.body,edge_above.shape)
					table.insert(objects.walls,edge_above)
				end
				if return_values.below then --etc,etc
					local edge_below = {}
					edge_below.body = love.physics.newBody(world,0,0)
					edge_below.shape = love.physics.newEdgeShape(bottom_left[1],bottom_left[2],bottom_right[1],bottom_right[2])
					edge_below.fixture = love.physics.newFixture(edge_below.body,edge_below.shape)
					table.insert(objects.walls,edge_below)
				end
				if return_values.right then --etc,etc
					local edge_right = {}
					edge_right.body = love.physics.newBody(world,0,0)
					edge_right.shape = love.physics.newEdgeShape(top_right[1],top_right[2],bottom_right[1],bottom_right[2])
					edge_right.fixture = love.physics.newFixture(edge_right.body,edge_right.shape)
					table.insert(objects.walls,edge_right)
				end
				if return_values.left then --etc,etc
					local edge_left = {}
					edge_left.body = love.physics.newBody(world,0,0)
					edge_left.shape = love.physics.newEdgeShape(top_left[1],top_left[2],bottom_left[1],bottom_left[2])
					edge_left.fixture = love.physics.newFixture(edge_left.body,edge_left.shape)
					table.insert(objects.walls,edge_left)
				end
			end
		end
	end
	print(#objects.walls)]]
end

function love.update(dt)
    world:update(dt)
    objects.player:update()
    Camera:lookAt(objects.player.body:getX(), objects.player.body:getY())
end

function love.keyreleased(key)
	if key == "w" or key == "a" or key == "s" or key == "d" then
		local body_x_velocity, body_y_velocity = objects.player.body:getLinearVelocity()
		local is_moving = {}
		is_moving.up = love.keyboard.isDown("w")
		is_moving.down = love.keyboard.isDown("s")
		is_moving.left = love.keyboard.isDown("a")
		is_moving.right = love.keyboard.isDown("d")
		
		if not(is_moving.up or is_moving.down) then
			objects.player.body:setLinearVelocity(body_x_velocity,0)
		elseif not(is_moving.left or is_moving.right) then
			objects.player.body:setLinearVelocity(0,body_y_velocity)
		end
	end	
end

function love.draw()
	Camera:attach()
	love.graphics.setColor(255,255,255)
	draw_map(map,96,96,tileset_quads,tileset)
	
	for i,v in ipairs(objects.walls) do
		love.graphics.setColor(0,255,0)
		love.graphics.line(v.body:getWorldPoints(v.shape:getPoints()))
	end
	love.graphics.setColor(255,255,255)
	love.graphics.polygon("fill", objects.player.body:getWorldPoints(objects.player.shape:getPoints()))
	Camera:detach()
end

function love.mousepressed(x,y,button)

end